@@ -138,7 +138,7 @@ def _compare_nonsat_postfit_residuals(diffstd,log_lvl,tol=None):
     if diff_count.empty: #no non-sat records found such as Zamb
         _logging.warning(f':diffutil non-SVs residuals not present. Skipping')
         return 0
-    diff_count =  diff_count.droplevel('SAT').unstack(['SITE','TYPE','BLK'])
+    diff_count =  diff_count.droplevel('SAT').unstack(['TYPE','NUM','SITE','BLK'])
     bad_nonsv_residuals = _diff2msg(diff_count,tol=tol)
     if bad_nonsv_residuals is not None:
         _logging.log(msg=f':diffutil found non-SVs residuals diffs above {"the extracted STDs" if tol is None else f"{tol:.1E} tolerance"}:\n{bad_nonsv_residuals.to_string(justify="center")}\n',level=log_lvl)
